@@ -14,6 +14,7 @@
 #include "signals.h"
 #include "formats.h"
 #include "loader.h"
+#include "logger.h"
 #include "status.h"
 #include "recovery.h"
 #include "config.h"
@@ -74,6 +75,7 @@ static void fix_state(void)
 
 static void inc_format_error(char *charset)
 {
+	log_event("! Incorrect charset file format: %.100s", charset);
 	fprintf(stderr, "Incorrect charset file format: %s\n", charset);
 	error();
 }
@@ -87,6 +89,8 @@ static void inc_new_length(unsigned int length,
 	char *buffer;
 	int count;
 
+	log_event("- Switching to length %d", length + 1);
+
 	char1[0] = 0;
 	if (length)
 		memset(char2, 0, sizeof(*char2));
@@ -160,7 +164,9 @@ static void inc_new_length(unsigned int length,
 	} while (value != EOF);
 
 	if (value == EOF) {
-		if (ferror(file)) pexit("getc"); else
+		if (ferror(file))
+			pexit("getc");
+		else
 			inc_format_error(charset);
 	}
 }
@@ -192,6 +198,9 @@ static void inc_new_count(unsigned int length, int count,
 	int pos, i, j;
 	int size;
 
+	log_event("- Expanding tables for length %d to character count %d",
+		length + 1, count + 1);
+
 	size = count + 2;
 
 	expand(char1, allchars, size);
@@ -326,7 +335,10 @@ void do_incremental_crack(struct db_main *db, char *mode)
 			mode = "All";
 	}
 
+	log_event("Proceeding with \"incremental\" mode: %.100s", mode);
+
 	if (!(charset = cfg_get_param(SECTION_INC, mode, "File"))) {
+		log_event("! No charset defined");
 		fprintf(stderr, "No charset defined for mode: %s\n", mode);
 		error();
 	}
@@ -340,12 +352,16 @@ void do_incremental_crack(struct db_main *db, char *mode)
 	max_count = cfg_get_int(SECTION_INC, mode, "CharCount");
 
 	if (min_length > max_length) {
+		log_event("! MinLen = %d exceeds MaxLen = %d",
+			min_length, max_length);
 		fprintf(stderr, "MinLen = %d exceeds MaxLen = %d\n",
 			min_length, max_length);
 		error();
 	}
 
 	if (max_length > CHARSET_LENGTH) {
+		log_event("! MaxLen = %d exceeds the compile-time limit of %d",
+			max_length, CHARSET_LENGTH);
 		fprintf(stderr,
 			"\n"
 			"MaxLen = %d exceeds the compile-time limit of %d\n\n"
@@ -371,12 +387,11 @@ void do_incremental_crack(struct db_main *db, char *mode)
 	if (ferror(file)) pexit("fread");
 
 	if (feof(file) ||
-		memcmp(header->version, CHARSET_VERSION,
-			sizeof(header->version)) ||
-		header->min != CHARSET_MIN || header->max != CHARSET_MAX ||
-		header->length != CHARSET_LENGTH ||
-		header->count > CHARSET_SIZE ||
-		!header->count) inc_format_error(charset);
+	    memcmp(header->version, CHARSET_VERSION, sizeof(header->version)) ||
+	    header->min != CHARSET_MIN || header->max != CHARSET_MAX ||
+	    header->length != CHARSET_LENGTH ||
+	    header->count > CHARSET_SIZE || !header->count)
+		inc_format_error(charset);
 
 	fread(allchars, header->count, 1, file);
 	if (ferror(file)) pexit("fread");
@@ -387,10 +402,20 @@ void do_incremental_crack(struct db_main *db, char *mode)
 		expand(allchars, extra, sizeof(allchars));
 	real_count = strlen(allchars);
 
-	if (max_count < 0) max_count = CHARSET_SIZE; else
-	if ((unsigned int)max_count > real_count)
-		fprintf(stderr, "Warning: only %d characters available\n",
+	if (max_count < 0) max_count = CHARSET_SIZE;
+
+	if (min_length != max_length)
+		log_event("- Lengths %d to %d, up to %d different characters",
+			min_length, max_length, max_count);
+	else
+		log_event("- Length %d, up to %d different characters",
+			min_length, max_count);
+
+	if ((unsigned int)max_count > real_count) {
+		log_event("! Only %u characters available", real_count);
+		fprintf(stderr, "Warning: only %u characters available\n",
 			real_count);
+	}
 
 	if (header->length >= 2)
 		char2 = (char2_table)mem_alloc(sizeof(*char2));
@@ -449,6 +474,9 @@ void do_incremental_crack(struct db_main *db, char *mode)
 			if (crk_process_key("")) break;
 		}
 
+		log_event("- Trying length %d, fixed @%d, character count %d",
+			length + 1, fixed + 1, count + 1);
+
 		if (inc_key_loop(length, fixed, count, char1, char2, chars))
 			break;
 	}
