@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-99 by Solar Designer
+ * Copyright (c) 1996-99,2003 by Solar Designer
  */
 
 #include <stdio.h>
@@ -10,8 +10,13 @@
 #include <stdarg.h>
 #include <errno.h>
 
+#include "logger.h"
+
 void error(void)
 {
+	log_event("Terminating on error");
+	log_done();
+
 	exit(1);
 }
 
